pydevDAG._decorations._decorators module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._decorations package »

# pydevDAG._decorations._decorators module

## pydevDAG._decorations._decorators

Tools to decorate networkx graphs in situ, i.e., as constructed rather than as read from a textual file.

class `pydevDAG._decorations._decorators.` `DifferenceMarkers`

  Bases: `object`

  Difference markers, either added or removed or present.

  static `edge_differences`(graph, difference, value)

    Get edge differences in `graph` based on `difference`.

    Parameters: | graph (DiGraph) – the graph difference (DiGraph) – a graph representing the difference value (str) – marker to add to graph

    If edge is in difference, adds `value` as “diffstatus” attribute.

  static `node_differences`(graph, difference, value)

    Get node differences in `graph` based on `difference`.

    Parameters: | graph (DiGraph) – the graph difference (DiGraph) – a graph representing the difference value (str) – marker to add to graph

    If node is in difference, adds `value` as “diffstatus” attribute.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._decorations package »